#erase everything on the workspace
rm(list=ls())
 
#setting work environment
setwd("F:/Documentos/1.1.Proyectos/12. Defining shell whorl cross section/Scripts")

#loading packages

library(randomcoloR)
library(Morpho)
library(geomorph)
library(ggplot2)
library(morphospace)


#translating .txt files containing Seminlandmark data to TPS file
read_files <- lapply(paste0('50_compilation_56SL/', 
                            list.files('50_compilation_56SL')), 'read.table')
tps <- array(unlist(read_files), dim=c(dim(read_files[[1]]), 
                                       length(read_files)), dimnames=list(rownames(read_files[[1]]), 
                                                                          NULL, gsub('[.]txt$', '', list.files('50_compilation_56SL'))))
#checking the dataset
tps

#Generalized procrustes analysis
gpa <- procSym(dataarray = tps ) #the conformation were already aligned, further alignment is not required.
summary (gpa)

var<-gpa$Variance
var
CS <- gpa$size #centroid size
ms <- gpa$mshape # mean shape or consensus
confs<- gpa$orpdata #transformed configurations
scores<--gpa$PCscores
scores
#checking the orientation of the SL configurations
plot(ms) 
#rotate the SL configurations
msr<-rotate.coords(ms, type = "rotateC")
plot (msr)
confsr<- rotate.coords(confs, type = "rotateC")

df0<-cbind.data.frame(msr)

consensus<-ggplot(df0, 
                  aes(df0[,1], df0[,2]))+ geom_point() + 
  labs(x="x", y="y")+theme_bw()+  geom_path() 
consensus


#plotting the results



df<-cbind.data.frame(CS,scores)

tot_scores = as.matrix(cbind(scores, -scores)) 

dimnames(tot_scores) <-list(rep("", dim(tot_scores)[1]), rep("", dim(tot_scores)[2]))

tot_scores

ggplot(df, 
       aes(PC1, PC2))+ geom_point() + 
  labs(x="PC1", y="PC2")+ xlim(-0.5,0.5)+ylim(-0.4,0.4)+theme_bw()

mspace(confsr,axes = c(1, 2),  cex.ldm = 0.05,nv=10, nh=12, points = T,size.models = 2 )
points(tot_scores[,c(14,15)], col ="black", pch = 19,cex = 1)

mspace(confsr,axes = c(1, 3),  cex.ldm = 0.05,nv=10, nh=12, points = T,size.models = 2 )
points(tot_scores[,c(14,16)], col ="black", pch = 19,cex = 1)

#plotting PCs against the size
ggplot(df, 
       aes(CS, PC1))+ geom_point() + 
  labs(x="CS", y="PC1")+ylim(-0.5,0.5)
ggplot(df, 
       aes(CS,PC2 ))+ geom_point() + 
  labs(x="CS", y="PC2")+ylim(-0.3,0.4)

#predicted configurations

pc <- 1 # specify principal component
pcvecs <- gpa$PCs 
ext_shapes_PC <- restoreShapes (scores = c(-0.4, 0.4),
                                PC = pcvecs[, pc],
                                mshape = ms)
print(ext_shapes_PC [,, 1])
exshape<-ext_shapes_PC [,, 1]
exshaper<- rotate.coords(exshape, type = "rotateC")

print(exshaper)
plot(exshaper)
text(exshaper, labels = 1:nrow(ms), asp = 0.5)


print(ext_shapes_PC [,, 2])
exshape2<-ext_shapes_PC [,, 2]
exshape2r<- rotate.coords(exshape2, type = "rotateC")
plot(exshape2r)
text(exshape2r, labels = 1:nrow(msr), asp = 0.5)


print(exshape2r)

exshape<- rotate.coords(exshape, type = "rotateC")
exshape2<- rotate.coords(exshape2, type = "rotateC")

plot(exshape, col = "red", pch = 16, ylim = c(-0.3, 0.3),xlim = c(-0.3, 0.3), xlab= "X",ylab= "Y")
points(exshape2, col = "blue", pch = 16)

# Export the results

write.csv(scores, "results/scores_GM_56SL.csv", row.names = TRUE)
write.csv(CS, "results/Csize_GM_56SL.csv", row.names = TRUE)
write.csv(var, "results/variation_GM_56SL.csv", row.names = TRUE)
write.csv(msr, "results/consensus_GM_56SL.csv", row.names = TRUE)

